==> jinrousiki-1.3.1.zip: jinrousiki-1.3.1/include/message_class.php <==
<?php
// ƥåǼ饹
class Message{
  //-- room_manger.php --//
  //CreateRoom() : ¼
  //귯Υ
  var $dummy_boy_comment = 'ͤϤʤ';

  //귯ΰ
  var $dummy_boy_last_words = 'ͤϤʤäƸäΤˡġ';

  //-- user_manager.php --//
  //EntryUser() : 桼Ͽ
  //¼å
  // var $entry_user = '¼νˤäƤޤ'
  // var $entry_user = '۶ꤷޤ';
  var $entry_user = '¼λҲˤäƤޤ';

  //-- game_view.php & OutputGameHTMLHeader() --//
  var $vote_announce = '֤ޤɼƤ'; //ä»ڤ

  //-- game_functions.php --//
  //OutputVictory() : ¼ܿͤξԷ
  //¼;
  var $victory_human = '[¼;] ¼ͤϿϵη䤹뤳Ȥޤ';

  //ϵ;
  var $victory_wolf = '[ϵ;] Ǹΰͤ򿩤ȿϵãϼγʪ¼ˤ';

  //ŸѾ (¼;)
  var $victory_fox1 = '[ŸѾ] ϵʤʤäŨʤɤ⤦ʤ';

  //ŸѾ (ϵ)
  var $victory_fox2 = '[ŸѾ] ޥ̥ʿϵɤ٤ȤʤưפȤ';

  //͡塼ԥåɾ
  var $victory_lovers = '[͡塼ԥåɾ] ˤϲԤ̵ϤäΤǤ';

  //ʬ
  var $victory_draw = '[ʬ] ʬȤʤޤ';

  //
  var $victory_vanish = '[ʬ] ïʤʤäġ';

  //¼
  var $victory_none = '¤ʹԤƿͤʤʤޤ';

  var $win  = 'ʤϾޤ'; //ܿ;
  var $lose = 'ʤ̤ޤ'; //ܿ
  var $draw = 'ʬȤʤޤ'; //ʬ

  //OutputReVoteList() : ɼʥ
  var $revote = 'ɼȤʤޤ'; //ɼ
  var $draw_announce = 'ɼȤʤȰʬˤʤޤ'; //ʬ

  //OutputTalkLog() : áƥå
  var $objection = 'ְ۵ġפ򿽤ΩƤޤ'; //۵Ĥ
  //var $game_start = 'ϥ೫Ϥɼޤ' //೫ɼ //ߤԻ
  var $kick_do  = ' KICK ɼޤ'; //KICK ɼ
  var $vote_do  = '˽跺ɼޤ';   //跺ɼ
  var $wolf_eat = 'Ĥޤ';   //ϵɼ
  var $mage_do  = 'ꤤޤ';           //ꤤդɼ
  var $guard_do = 'θҤդޤ';   //ͤɼ
  var $cupid_do = '˰ޤ'; //塼ԥåɤɼ

  var $morning_header = 'ī'; //īΥإå
  var $morning_footer = 'ܤīäƤޤ'; //īΥեå
  var $night = 'ŤŤ뤬äƤޤ'; //
  var $dummy_boy = '귯'; //GM⡼ѥإå

  var $wolf_howl = '󡦡'; //ϵαʤ
  var $common_talk = 'ҥҥ'; //ͭԤξ

  //OutputLastWords() : ɽ
  var $lastwords = '뤬˴ʤäΰ񤬸Ĥޤ';

  //OutoutDeadManType() : ɽ
  var $deadman         = '̵ĤʻѤȯޤ'; //ɽå
  var $wolf_killed     = 'ϵα¿ˤʤä褦Ǥ'; //ϵν
  var $fox_dead        = '(Ÿ) ꤤդ˼줿褦Ǥ'; //Ѽ
  var $poison_dead     = 'Ǥ˴褦Ǥ'; //ǼԤƻϢ
  var $vote_killed     = 'ɼη̽跺ޤ'; //ߤ
  var $lovers_followed = 'ͤθɤޤ'; //ͤθɤ

  //OutputAbility() : ǽϤɽ
  var $ability_dead     = 'ʥ©䤨ޤ';     //Ǥ
  var $ability_wolf_eat = 'ͤ򤷤Ƥ';   //ϵɼ
  var $ability_mage_do  = 'ꤦͤ򤷤Ƥ';       //ꤤդɼ
  var $ability_guard_do = 'Ҥͤ򤷤Ƥ';   //ͤɼ
  var $ability_cupid_do = 'ӤĤͤǤ'; //塼ԥåɤɼ

  //-- game_play.php --//
  //CheckSilence()
  var $silence = 'ۤɤۤ³'; //ۤǻַв (äǻַв)
  //ηٹå
  // var $sudden_death_announce = 'ɼλʤϻषϹĤƤޤޤ';
  var $sudden_death_announce = 'ɼλʤϥꤵƤޤޤ';
  // var $sudden_death = '˴ʤˤʤޤ'; //
  var $sudden_death = 'ϻϢޤ'; //

  //ɼꥻå
  var $vote_reset = 'ɼꥻåȤޤɼƤ';

  //-- game_vote.php --//
  //Kick ¼ä
  var $kick_out = 'ʤ򤢤錄¼ޤ';

  //OutputVoteBeforeGame()
  var $submit_kick_do    = 'оݤ򥭥å˰ɼ'; //Kick ɼܥ
  var $submit_game_start = '򳫻Ϥ˰ɼ'; //೫ϥܥ

  //OutputVoteDay()
  var $submit_vote_do = 'оݤ跺˰ɼ'; //跺ɼܥ

  //OutputVoteNight()
  var $submit_wolf_eat = 'оݤ ()'; //ϵνܥ
  var $submit_mage_do  = 'оݤꤦ'; //ꤤդɼܥ
  var $submit_guard_do = 'оݤҤ'; //ͤɼܥ
  var $submit_cupid_do = 'оݤ˰'; //塼ԥåɤɼܥ
}
?>

==> jinrousiki-1.3.4.zip: jinrousiki-1.3.4/include/message_class.php <==
<?php
// ƥåǼ饹
class Message{
  //-- room_manger.php --//
  //CreateRoom() : ¼
  //귯Υ
  var $dummy_boy_comment = 'ͤϤʤ';

  //귯ΰ
  var $dummy_boy_last_words = 'ͤϤʤäƸäΤˡġ';

  //-- user_manager.php --//
  //EntryUser() : 桼Ͽ
  //¼å
  var $entry_user = '¼νˤäƤޤ'

  //-- game_view.php & OutputGameHTMLHeader() --//
  var $vote_announce = '֤ޤɼƤ'; //ä»ڤ

  //-- game_functions.php --//
  //OutputVictory() : ¼ܿͤξԷ
  //¼;
  var $victory_human = '[¼;] ¼ͤϿϵη䤹뤳Ȥޤ';

  //ϵ;
  var $victory_wolf = '[ϵ;] Ǹΰͤ򿩤ȿϵãϼγʪ¼ˤ';

  //ŸѾ (¼;)
  var $victory_fox1 = '[ŸѾ] ϵʤʤäŨʤɤ⤦ʤ';

  //ŸѾ (ϵ)
  var $victory_fox2 = '[ŸѾ] ޥ̥ʿϵɤ٤ȤʤưפȤ';

  //͡塼ԥåɾ
  var $victory_lovers = '[͡塼ԥåɾ] ˤϲԤ̵ϤäΤǤ';

  //ʬ
  var $victory_draw = '[ʬ] ʬȤʤޤ';

  //
  var $victory_vanish = '[ʬ] ïʤʤäġ';

  //¼
  var $victory_none = '¤ʹԤƿͤʤʤޤ';

  var $win  = 'ʤϾޤ'; //ܿ;
  var $lose = 'ʤ̤ޤ'; //ܿ
  var $draw = 'ʬȤʤޤ'; //ʬ

  //OutputReVoteList() : ɼʥ
  var $revote = 'ɼȤʤޤ'; //ɼ
  var $draw_announce = 'ɼȤʤȰʬˤʤޤ'; //ʬ

  //OutputTalkLog() : áƥå
  var $objection = 'ְ۵ġפ򿽤ΩƤޤ'; //۵Ĥ
  //var $game_start = 'ϥ೫Ϥɼޤ' //೫ɼ //ߤԻ
  var $kick_do  = ' KICK ɼޤ'; //KICK ɼ
  var $vote_do  = '˽跺ɼޤ';   //跺ɼ
  var $wolf_eat = 'Ĥޤ';   //ϵɼ
  var $mage_do  = 'ꤤޤ';           //ꤤդɼ
  var $guard_do = 'θҤդޤ';   //ͤɼ
  var $cupid_do = '˰ޤ'; //塼ԥåɤɼ

  var $morning_header = 'ī'; //īΥإå
  var $morning_footer = 'ܤīäƤޤ'; //īΥեå
  var $night = 'ŤŤ뤬äƤޤ'; //
  var $dummy_boy = '귯'; //GM⡼ѥإå

  var $wolf_howl = '󡦡'; //ϵαʤ
  var $common_talk = 'ҥҥ'; //ͭԤξ

  //OutputLastWords() : ɽ
  var $lastwords = '뤬˴ʤäΰ񤬸Ĥޤ';

  //OutoutDeadManType() : ɽ
  var $deadman         = '̵ĤʻѤȯޤ'; //ɽå
  var $wolf_killed     = 'ϵα¿ˤʤä褦Ǥ'; //ϵν
  var $fox_dead        = '(Ÿ) ꤤդ˼줿褦Ǥ'; //Ѽ
  var $poison_dead     = 'Ǥ˴褦Ǥ'; //ǼԤƻϢ
  var $vote_killed     = 'ɼη̽跺ޤ'; //ߤ
  var $lovers_followed = 'ͤθɤޤ'; //ͤθɤ

  //OutputAbility() : ǽϤɽ
  var $ability_dead     = 'ʥ©䤨ޤ';     //Ǥ
  var $ability_wolf_eat = 'ͤ򤷤Ƥ';   //ϵɼ
  var $ability_mage_do  = 'ꤦͤ򤷤Ƥ';       //ꤤդɼ
  var $ability_guard_do = 'Ҥͤ򤷤Ƥ';   //ͤɼ
  var $ability_cupid_do = 'ӤĤͤǤ'; //塼ԥåɤɼ

  //-- game_play.php --//
  //CheckSilence()
  var $silence = 'ۤɤۤ³'; //ۤǻַв (äǻַв)
  //ηٹå
  var $sudden_death_announce = 'ɼλʤϻषϹĤƤޤޤ';
  var $sudden_death = '˴ʤˤʤޤ'; //

  //ɼꥻå
  var $vote_reset = 'ɼꥻåȤޤɼƤ';

  //-- game_vote.php --//
  //Kick ¼ä
  var $kick_out = 'ʤ򤢤錄¼ޤ';

  //OutputVoteBeforeGame()
  var $submit_kick_do    = 'оݤ򥭥å˰ɼ'; //Kick ɼܥ
  var $submit_game_start = '򳫻Ϥ˰ɼ'; //೫ϥܥ

  //OutputVoteDay()
  var $submit_vote_do = 'оݤ跺˰ɼ'; //跺ɼܥ

  //OutputVoteNight()
  var $submit_wolf_eat = 'оݤ ()'; //ϵνܥ
  var $submit_mage_do  = 'оݤꤦ'; //ꤤդɼܥ
  var $submit_guard_do = 'оݤҤ'; //ͤɼܥ
  var $submit_cupid_do = 'оݤ˰'; //塼ԥåɤɼܥ
}
?>
